/**
 * This program has been developed by a student from the bachelor Information Science at
 * Utrecht University within the Research Project course.
 * © Copyright Utrecht University (Department of Information and Computing Sciences)
 */

const formatData = (data: { [key: string]: any }) => {
  let result = '';

  for (const key in data) {
    if (typeof data[key] === 'object') {
      result += `${key}:<br>${formatData(data[key])}`;
    } else {
      result += `${key}: ${data[key]}<br>`;
    }
  }

  return result;
};

export const getTooltip = (object: any) => {
  if (object && object.isEdge) {
    const { from, to } = object;
    const attributes = formatData(object);
    return {
      html: `
        <div>
          <h3>${from}-${to}</h3>
          <p>${attributes}</p>
        </div>
      `,
    };
  } else if (object && object.isNode && object.data.hasOwnProperty('locations')) {
    const { id, lon, lat, data } = object;
    return {
      html: `
        <div>
          <h3>Id: ${id}</h3>
          <p>Location: ${lon.toFixed(2)}-${lat.toFixed(2)}</p>
          <p>City: ${data.locations.slice(0, 5)}...</p>
        </div>
      `,
    };
  } else if (object && object.hasOwnProperty('properties') && object.properties.cluster) {
    const { id } = object;
    const attributes = formatData(object);
    return {
      html: `
        <div>
          <h3>Id: ${id}</h3>
          <p>${attributes}</p>
        </div>
      `,
    };
  } else if (object && object.hasOwnProperty('geometry')) {
    const { geometry, properties } = object;
    return {
      html: `
        <div>
          <h3>Airport: ${properties.id}</h3>
          <p>City: ${properties.data.city}</p>
        </div>
      `,
    };
  } else if (object && object.hasOwnProperty('id') && object.data.hasOwnProperty('prediction')) {
    const { from, to, count, data } = object;
    const test = formatData(data);
    return {
      html: `
        <div>
          <h3>${from}-${to}</h3>
          <p>Flight count: ${count}</p>
          <p>Predicted passengers: ${data.prediction}</p>
        </div>
      `,
    };
  } else if (object && object.isNode) {
    const { id, data } = object;
    const attributes = formatData(data);
    return {
      html: `
        <div>
          <h3>Id: ${id}</h3>
          <p>${attributes}</p>

        </div>
      `,
    };
  } else {
    return null;
  }
};
