/**
 * This program has been developed by a student from the bachelor Information Science at
 * Utrecht University within the Research Project course.
 * © Copyright Utrecht University (Department of Information and Computing Sciences)
 */

export type Coordinates = [number, number];

export interface GeoNodeType {
  id: string;
  [key: string]: any;
  attributes: {
    coordinates: Coordinates;
    [key: string]: any;
  };
}

export interface GeoEdgeType {
  id: string;
  from: string;
  to: string;
  [key: string]: any;
  attributes: {
    [key: string]: any;
  };
}

export interface Node {
  id: string;
  [key: string]: any;
  attributes: {
    coordinates: Coordinates;
    [key: string]: any;
  };
}

export interface Edge {
  id: string;
  from: string;
  to: string;
  [key: string]: any;
  attributes: {
    [key: string]: any;
  };
}

export interface GeoGraphType {
  nodes: GeoNodeType[];
  edges: GeoEdgeType[];
  [key: string]: any;
}

export interface Command {
  execute: (data: GeoGraphType) => GeoGraphType;
}

export interface ViewModel {
  data: GeoGraphType;
  executeCommand: (command: Command) => void;
  addCoordinatesToEdges: () => void;
}

export interface Bundle {
  [key: string]: Edge[];
}

export interface BundledEdge extends Edge {
  from: string;
  to: string;
  color: number[];
  numEdges: number;
  from_coordinates: number[];
  to_coordinates: number[];
}

export interface BundleDict {
  [key: string]: Bundle;
}

export interface Viewport {
  [key: string]: any;
}

export interface LayerProps {
  data: GeoGraphType;
  config: {
    heatmap: Record<string, unknown>;
    nodes: Record<string, unknown>;
    edges: Record<string, unknown>;
  };
  [key: string]: any;
}

export interface MapProps {
  graph: ViewModel | null;
  mapType: number;
  isAggregated: boolean;
  isFanned: boolean;
}
